Documentation
¶
Overview ¶
Package v1 contains API Schema definitions for the infra v1 API group +kubebuilder:object:generate=true +groupName=infra.31780.com
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "infra.31780.com", Version: "v1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type AutoScaler ¶
type AutoScaler struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec AutoScalerSpec `json:"spec,omitempty"`
Status AutoScalerStatus `json:"status,omitempty"`
}
AutoScaler is the Schema for the autoscalers API
func (*AutoScaler) DeepCopy ¶
func (in *AutoScaler) DeepCopy() *AutoScaler
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AutoScaler.
func (*AutoScaler) DeepCopyInto ¶
func (in *AutoScaler) DeepCopyInto(out *AutoScaler)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AutoScaler) DeepCopyObject ¶
func (in *AutoScaler) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type AutoScalerList ¶
type AutoScalerList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []AutoScaler `json:"items"`
}
AutoScalerList contains a list of AutoScaler
func (*AutoScalerList) DeepCopy ¶
func (in *AutoScalerList) DeepCopy() *AutoScalerList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AutoScalerList.
func (*AutoScalerList) DeepCopyInto ¶
func (in *AutoScalerList) DeepCopyInto(out *AutoScalerList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AutoScalerList) DeepCopyObject ¶
func (in *AutoScalerList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type AutoScalerSpec ¶
type AutoScalerSpec struct {
ScalePercentage int `json:"scalePercentage,omitempty"` // Scale by this percentage
ScaleTime string `json:"scaleTime,omitempty"` // Time to scale, e.g. (challenge info) "08:50AM"
Duration int `json:"duration,omitempty"` // Duration in minutes
DeploymentName string `json:"deploymentName,omitempty"` // Target deployment name
}
AutoScalerSpec defines the desired state of AutoScaler
func (*AutoScalerSpec) DeepCopy ¶
func (in *AutoScalerSpec) DeepCopy() *AutoScalerSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AutoScalerSpec.
func (*AutoScalerSpec) DeepCopyInto ¶
func (in *AutoScalerSpec) DeepCopyInto(out *AutoScalerSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AutoScalerStatus ¶
type AutoScalerStatus struct {
LastScaledTime metav1.Time `json:"lastScaledTime,omitempty"` // Track the last time scaling last occurred
}
AutoScalerStatus defines the observed state of AutoScaler
func (*AutoScalerStatus) DeepCopy ¶
func (in *AutoScalerStatus) DeepCopy() *AutoScalerStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AutoScalerStatus.
func (*AutoScalerStatus) DeepCopyInto ¶
func (in *AutoScalerStatus) DeepCopyInto(out *AutoScalerStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.